File 1342-Fix-typos-in-lib-inets.patch of Package erlang

From 45e4418577d1b6569b1f81c9c0085aa6976458c1 Mon Sep 17 00:00:00 2001
From: "Kian-Meng, Ang" <kianmeng@cpan.org>
Date: Fri, 17 Dec 2021 09:56:35 +0800
Subject: [PATCH] Fix typos in lib/inets

---
 lib/inets/doc/src/httpd.xml                   |  2 +-
 lib/inets/doc/src/httpd_util.xml              |  4 +--
 lib/inets/doc/src/notes.xml                   | 26 +++++++++----------
 lib/inets/doc/src/notes_history.xml           |  8 +++---
 .../examples/httpd_load_test/hdlt_client.erl  |  2 +-
 .../examples/httpd_load_test/hdlt_ctrl.erl    | 10 +++----
 .../examples/httpd_load_test/hdlt_slave.erl   |  2 +-
 .../examples/server_root/conf/httpd.conf      |  8 +++---
 lib/inets/examples/server_root/icons/README   |  2 +-
 lib/inets/src/http_client/httpc.erl           |  4 +--
 lib/inets/src/http_client/httpc_cookie.erl    |  2 +-
 lib/inets/src/http_client/httpc_handler.erl   |  8 +++---
 lib/inets/src/http_client/httpc_internal.hrl  |  2 +-
 lib/inets/src/http_client/httpc_manager.erl   |  8 +++---
 lib/inets/src/http_client/httpc_response.erl  |  6 ++---
 lib/inets/src/http_lib/http_chunk.erl         |  4 +--
 lib/inets/src/http_lib/http_transport.erl     |  6 ++---
 lib/inets/src/http_server/httpd.erl           |  2 +-
 lib/inets/src/http_server/httpd_acceptor.erl  |  2 +-
 lib/inets/src/http_server/httpd_conf.erl      | 12 ++++-----
 lib/inets/src/http_server/httpd_file.erl      |  2 +-
 lib/inets/src/http_server/httpd_request.erl   |  6 ++---
 .../src/http_server/httpd_request_handler.erl |  2 +-
 lib/inets/src/http_server/httpd_response.erl  |  6 ++---
 lib/inets/src/http_server/httpd_util.erl      |  2 +-
 lib/inets/src/http_server/mod_auth.erl        |  2 +-
 lib/inets/src/http_server/mod_auth_server.erl |  2 +-
 lib/inets/src/http_server/mod_disk_log.erl    |  4 +--
 lib/inets/src/http_server/mod_log.erl         |  2 +-
 lib/inets/src/http_server/mod_range.erl       |  6 ++---
 .../src/http_server/mod_responsecontrol.erl   |  8 +++---
 lib/inets/src/http_server/mod_security.erl    |  2 +-
 .../src/http_server/mod_security_server.erl   |  6 ++---
 lib/inets/src/inets_app/inets.erl             |  6 ++---
 lib/inets/src/inets_app/inets_lib.erl         |  4 +--
 lib/inets/src/inets_app/inets_service.erl     |  2 +-
 lib/inets/src/inets_app/inets_trace.erl       |  2 +-
 lib/inets/test/erl_make_certs.erl             |  2 +-
 lib/inets/test/http_format_SUITE.erl          |  8 +++---
 lib/inets/test/httpc_SUITE.erl                | 24 ++++++++---------
 lib/inets/test/httpc_cookie_SUITE.erl         |  6 ++---
 lib/inets/test/httpc_proxy_SUITE.erl          |  2 +-
 lib/inets/test/httpd_1_1.erl                  |  4 +--
 lib/inets/test/httpd_SUITE.erl                |  4 +--
 lib/inets/test/httpd_basic_SUITE.erl          |  2 +-
 lib/inets/test/httpd_mod.erl                  |  4 +--
 .../server_root/conf/httpd.conf               |  6 ++---
 .../httpd_test_data/server_root/icons/README  |  2 +-
 lib/inets/test/httpd_time_test.erl            |  8 +++---
 49 files changed, 128 insertions(+), 128 deletions(-)

diff --git a/lib/inets/doc/src/httpd.xml b/lib/inets/doc/src/httpd.xml
index 8974c30163..3b44a66340 100644
--- a/lib/inets/doc/src/httpd.xml
+++ b/lib/inets/doc/src/httpd.xml
@@ -989,7 +989,7 @@ Transport: TLS
 		connection
 	}).</code>
 
-    <p>To acess the record in your callback-module use:</p>
+    <p>To access the record in your callback-module use:</p>
     <code> -include_lib("inets/include/httpd.hrl").</code>
 
     <p>The fields of record <c>mod</c> have the following meaning:
diff --git a/lib/inets/doc/src/httpd_util.xml b/lib/inets/doc/src/httpd_util.xml
index ce5b3b1bfc..60a147399d 100644
--- a/lib/inets/doc/src/httpd_util.xml
+++ b/lib/inets/doc/src/httpd_util.xml
@@ -308,12 +308,12 @@
     </func>
 
     <func>
-      <name>split_script_path(RequestLine) -> Splitted</name>
+      <name>split_script_path(RequestLine) -> Split</name>
       <fsummary>Splits a <c>RequestLine</c> in a file reference to an executable, 
       and a <c>QueryString</c> or a <c>PathInfo</c>string.</fsummary>
       <type>
         <v>RequestLine = string()</v>
-        <v>Splitted = not_a_script | {Path, PathInfo, QueryString}</v>
+        <v>Split = not_a_script | {Path, PathInfo, QueryString}</v>
         <v>Path = QueryString = PathInfo = string()</v>
       </type>
       <desc>
diff --git a/lib/inets/doc/src/notes.xml b/lib/inets/doc/src/notes.xml
index 34827a02da..44cf28fa8a 100644
--- a/lib/inets/doc/src/notes.xml
+++ b/lib/inets/doc/src/notes.xml
@@ -1184,7 +1184,7 @@
       <list>
         <item>
           <p>
-	    Correct misstakes in ftp client introduced in inets-6.3.4</p>
+	    Correct mistakes in ftp client introduced in inets-6.3.4</p>
           <p>
 	    Own Id: OTP-14203 Aux Id: OTP-13982 </p>
         </item>
@@ -1290,7 +1290,7 @@
       <list>
         <item>
           <p>
-	    A debug message was accidently left enabled in the ftp
+	    A debug message was accidentally left enabled in the ftp
 	    client.</p>
           <p>
 	    Own Id: OTP-13712 Aux Id: seq13143 </p>
@@ -1711,7 +1711,7 @@
         <item>
           <p>
 	    Remove Server Side Include support from inets, as this is
-	    an old technic that has security issues and was not well
+	    an old technique that has security issues and was not well
 	    tested.</p>
           <p>
 	    *** POTENTIAL INCOMPATIBILITY ***</p>
@@ -1741,7 +1741,7 @@
         </item>
         <item>
           <p>
-	    httpc: Fix implementation of gracefull shudown to work as
+	    httpc: Fix implementation of graceful shudown to work as
 	    intended for keep alive connections not using pipelining.</p>
           <p>
 	    Own Id: OTP-12803</p>
@@ -1931,7 +1931,7 @@
       <list>
         <item>
           <p>
-	    httpd: Seperate timeout for TLS/SSL handshake from
+	    httpd: Separate timeout for TLS/SSL handshake from
 	    keepalive timeout</p>
           <p>
 	    Own Id: OTP-12013</p>
@@ -2286,7 +2286,7 @@
         <item>
           <p>
 	    httpc: Fixed persistent connection implementation that
-	    was broken by a patch to R13. The patch made persisten
+	    was broken by a patch to R13. The patch made persistent
 	    connections behaved the same way as pipelining.</p>
           <p>
 	    Own Id: OTP-10845</p>
@@ -2629,7 +2629,7 @@
 	  the address part is removed. This value is then supplied as the host 
 	  header. This can cause problems with some servers.
 	  A workaround for this is to use headers_as_is and provide the host
-	  header with the requst call. 
+	  header with the request call. 
 	  To solve this a new option has been added, 
 	  <seealso marker="httpc#ipv6_host_with_brackets">ipv6_host_with_brackets</seealso>. 
 	  This option specifies if the host value of the host header shall 
@@ -2971,7 +2971,7 @@
 	  in the previous implementation a race condition could occur causing 
 	  the manager to crash. </p>
 	  <p>This is now avoided by using proc_lib:init_ack and 
-	  gen_server:enter_loop to allow mor advanced initialization of 
+	  gen_server:enter_loop to allow more advanced initialization of 
 	  httpc_handlers without blocking the httpc_manger and eliminating 
 	  extra processes that can cause race conditions. </p>
           <p>Own Id: OTP-9246</p>
@@ -2984,7 +2984,7 @@
 	  The reason was that the connect call resulted in an exit with 
 	  reason <c>badarg</c> 
 	  (this was the same for both <c>ssl</c> and <c>gen_tcp</c>). </p>
-	  <p>Exits was not catched. This has now been improved. </p>
+	  <p>Exits was not caught. This has now been improved. </p>
           <p>Own Id: OTP-9289</p>
           <p>Aux Id: seq11845</p>
         </item>
@@ -3078,7 +3078,7 @@
 	    the manager process. For this reason, the manager did not
 	    clean up the request table., resulting in a memory leak.
 	    Also the manager did not create a monitor for the
-	    handler, so in an unforseen handler crash, this could
+	    handler, so in an unforeseen handler crash, this could
 	    also create a memory leak.</p>
           <p>
 	    Own Id: OTP-8739</p>
@@ -3312,7 +3312,7 @@
 
       <list>
         <item>
-	  <p>[httpc] - Badly formated error reason for errors occuring 
+	  <p>[httpc] - Badly formatted error reason for errors occurring 
             during initial connect to a server. 
             Also, the possible error reasons was 
             not properly documented.</p>
diff --git a/lib/inets/doc/src/notes_history.xml b/lib/inets/doc/src/notes_history.xml
index f7c821b2d8..bdb45016e3 100644
--- a/lib/inets/doc/src/notes_history.xml
+++ b/lib/inets/doc/src/notes_history.xml
@@ -1653,7 +1653,7 @@
 	<item>
 	  <p>HTTP client <em>now</em> updated to jnets-0.1.
 	    <br></br>
-	    Auther: Johan Blom of Mobile Arts AB.</p>
+	    Author: Johan Blom of Mobile Arts AB.</p>
 	  <p>(Own Id: OTP-4588)</p>
 	</item>
 	  </list>
@@ -1674,7 +1674,7 @@
 	<item>
 	  <p>HTTP client updated to jnets-0.1, now supporting proxy.
 	    <br></br>
-	    Auther: Johan Blom of Mobile Arts AB.</p>
+	    Author: Johan Blom of Mobile Arts AB.</p>
 	  <p>(Own Id: OTP-4552)</p>
 	    </item>
       </list>
@@ -1714,7 +1714,7 @@
       <list type="bulleted">
 	<item>Added HTTP client to the application. 
 	  <br></br>
-	  Auther: Johan Blom of Mobile Arts AB.</item>
+	  Author: Johan Blom of Mobile Arts AB.</item>
 	<item>FTP: More info in exit reason when socket operation fails.
 	  <br></br>
 	  (Own Id: OTP-4429)</item>
@@ -1744,7 +1744,7 @@
 	  (Aux Id: Seq 7417)</item>
 	<item>Added inets test suite to the release. Including the
 	  lightweight inets test server.</item>
-	<item>Incorrectly formated disk log entries.
+	<item>Incorrectly formatted disk log entries.
 	  <em>term_to_binary</em> was (incorrectly) used for the 
 	  external format. 
 	  <br></br>
diff --git a/lib/inets/examples/httpd_load_test/hdlt_client.erl b/lib/inets/examples/httpd_load_test/hdlt_client.erl
index 8e929fbf2b..c65471f142 100644
--- a/lib/inets/examples/httpd_load_test/hdlt_client.erl
+++ b/lib/inets/examples/httpd_load_test/hdlt_client.erl
@@ -272,7 +272,7 @@ client_loop(#state{mode = generating} = State) ->
     end;
 
 %% The client no longer issues any new requests, instead it 
-%% waits for replies for all the oustanding requests to 
+%% waits for replies for all the outstanding requests to 
 %% arrive.
 client_loop(#state{mode     = stopping, 
 		   time     = Time, 
diff --git a/lib/inets/examples/httpd_load_test/hdlt_ctrl.erl b/lib/inets/examples/httpd_load_test/hdlt_ctrl.erl
index 751d678fa9..c3236545da 100644
--- a/lib/inets/examples/httpd_load_test/hdlt_ctrl.erl
+++ b/lib/inets/examples/httpd_load_test/hdlt_ctrl.erl
@@ -294,10 +294,10 @@ prepare_server_host(#state{server_root      = ServerRoot,
 	    {connect_timeout,       ?SSH_CONNECT_TIMEOUT}], 
     case ssh_sftp:start_channel(Host, Opts) of
 	{ok, Sftp, ConnectionRef} ->
-	    ?DEBUG("sftp connection established - now transer server content",
+	    ?DEBUG("sftp connection established - now transfer server content",
 		   []),
 	    create_server_content(Sftp, ServerRoot, SocketType, CertFile),
-	    ?DEBUG("server content transfered - now close ssh connection ", 
+	    ?DEBUG("server content transferred - now close ssh connection ", 
 		   []),
 	    ssh:close(ConnectionRef),
 	    ?DEBUG("server preparation complete ", []),
@@ -414,7 +414,7 @@ prepare_client_host(WorkDir, SocketType, CertFile, #client{host = Host}) ->
 	    {connect_timeout,       ?SSH_CONNECT_TIMEOUT}], 
     case ssh_sftp:start_channel(Host, Opts) of
 	{ok, Sftp, ConnectionRef} ->
-	    ?DEBUG("sftp connection established - now transer client content",
+	    ?DEBUG("sftp connection established - now transfer client content",
 		   []),
 	    create_client_content(Sftp, WorkDir, SocketType, CertFile),
 	    ?DEBUG("client content transered - now close ssh connection ", []),
@@ -974,7 +974,7 @@ clean_up(#state{server_root = ServerRoot,
 		clients     = Clients}) ->
     ?DEBUG("begin server cleanup", []),
     server_clean_up(ServerRoot, WorkDir, Host),
-    ?DEBUG("begin lient cleanup", []),
+    ?DEBUG("begin client cleanup", []),
     clients_clean_up(WorkDir, Clients),
     ?DEBUG("cleanup done", []),
     ok.
@@ -1198,7 +1198,7 @@ help() ->
     io:format("hdlt:start(Options). Where options:~n "
 	      " ~n~p~n~n hdlt:start([]). -> hdlt:start(~p)~n~n",
 	      [[{send_rate, "integer()", 
-		 "Numer of outstanding requests that a client "
+		 "Number of outstanding requests that a client "
 		 "should have during the test to create a load situation."},
 		{clients, "[{path(), host()}]", "Paths to erlang and names of hosts to run clients on."},
 		{test_time, "{hours(), mins(), sec()}", 
diff --git a/lib/inets/examples/httpd_load_test/hdlt_slave.erl b/lib/inets/examples/httpd_load_test/hdlt_slave.erl
index d703e58524..185c8b0e51 100644
--- a/lib/inets/examples/httpd_load_test/hdlt_slave.erl
+++ b/lib/inets/examples/httpd_load_test/hdlt_slave.erl
@@ -40,7 +40,7 @@
 %% master in the description below.
 %%
 %% If hostname is the same for the master and the slave,
-%% the Erlang node will simply be spawned.  The only requirment for
+%% the Erlang node will simply be spawned.  The only requirement for
 %% this to work is that the 'erl' program can be found in PATH.
 %%
 %% If the master and slave are on different hosts, start/N uses
diff --git a/lib/inets/examples/server_root/conf/httpd.conf b/lib/inets/examples/server_root/conf/httpd.conf
index 3f9fde03b5..69d38c69b1 100644
--- a/lib/inets/examples/server_root/conf/httpd.conf
+++ b/lib/inets/examples/server_root/conf/httpd.conf
@@ -30,9 +30,9 @@ Port 8888
 # 
 # It is also possible to specify the ip-family with the directive.
 # There ar three possible value: inet, inet6 and inet6fb4
-# inet:     Use IpFamily inet when retreiving the address and
+# inet:     Use IpFamily inet when retrieving the address and
 #           fail if that does not work.
-# inet6:    Use IpFamily inet6 when retreiving the address and
+# inet6:    Use IpFamily inet6 when retrieving the address and
 #           fail if that does not work.
 # inet6fb4: First IpFamily inet6 is tried and if that does not work, 
 #           inet is used as fallback. 
@@ -128,7 +128,7 @@ SecurityDiskLogSize 200000 10
 
 MaxClients 50
 
-# KeepAlive set the flag for persistent connections. For peristent connections
+# KeepAlive set the flag for persistent connections. For persistent connections
 # set KeepAlive to on. To use One request per connection set the flag to off
 # Note: The value has changed since previous version of INETS.
 KeepAlive on
@@ -206,7 +206,7 @@ SSLCertificateFile /var/tmp/server_root/ssl/ssl_server.pem
 SSLCertificateKeyFile /var/tmp/server_root/ssl/ssl_server.pem
 
 # Set SSLVerifyClient to:
-# 0 if no certicate is required
+# 0 if no certificate is required
 # 1 if the client may present a valid certificate
 # 2 if the client must present a valid certificate
 # 3 if the client may present a valid certificate but it is not required to
diff --git a/lib/inets/examples/server_root/icons/README b/lib/inets/examples/server_root/icons/README
index a1fc5a5a9c..c53bba67c4 100644
--- a/lib/inets/examples/server_root/icons/README
+++ b/lib/inets/examples/server_root/icons/README
@@ -46,7 +46,7 @@ Please feel free to tweak and rename the icons as you like.
           This can be used as a placeholder or a spacing element.
 
      bomb.gif
-          This can be used to repreesnt core files.
+          This can be used to represent core files.
 
      box1.gif, box2.gif
           These icons can be used to represent generic 3D applications and
diff --git a/lib/inets/src/http_client/httpc.erl b/lib/inets/src/http_client/httpc.erl
index 1fd65027ee..96906148c7 100644
--- a/lib/inets/src/http_client/httpc.erl
+++ b/lib/inets/src/http_client/httpc.erl
@@ -140,7 +140,7 @@ request(Url, Profile) ->
 %%      SendAcc = NewSendAcc = term()
 %%
 %% Description: Sends a HTTP-request. The function can be both
-%% syncronus and asynchronous in the later case the function will
+%% synchronous and asynchronous in the later case the function will
 %% return {ok, RequestId} and later on a message will be sent to the
 %% calling process on the format {http, {RequestId, {StatusLine,
 %% Headers, Body}}} or {http, {RequestId, {error, Reason}}}
@@ -652,7 +652,7 @@ maybe_format_body(BinBody, Options) ->
     end.
 
 %% This options is a workaround for http servers that do not follow the 
-%% http standard and have case sensative header parsing. Should only be
+%% http standard and have case sensitive header parsing. Should only be
 %% used if there is no other way to communicate with the server or for
 %% testing purpose.
 headers_as_is(Headers, Options) ->
diff --git a/lib/inets/src/http_client/httpc_cookie.erl b/lib/inets/src/http_client/httpc_cookie.erl
index bdd2d17e8b..6d18f62b46 100644
--- a/lib/inets/src/http_client/httpc_cookie.erl
+++ b/lib/inets/src/http_client/httpc_cookie.erl
@@ -375,7 +375,7 @@ parse_set_cookie(CookieHeader, {DefaultPath, DefaultDomain}) ->
 				   value = string:strip(Value)},
     Attributes      = parse_set_cookie_attributes(Attrs),
     TmpCookie       = cookie_attributes(Attributes, Cookie),
-    %% Add runtime defult values if necessary
+    %% Add runtime default values if necessary
     NewCookie       = domain_default(path_default(TmpCookie, DefaultPath), 
 				     DefaultDomain),
     NewCookie.
diff --git a/lib/inets/src/http_client/httpc_handler.erl b/lib/inets/src/http_client/httpc_handler.erl
index 1b8e81aa07..615314ac1d 100644
--- a/lib/inets/src/http_client/httpc_handler.erl
+++ b/lib/inets/src/http_client/httpc_handler.erl
@@ -212,7 +212,7 @@ stream(BodyPart, Request,_) -> % only 200 and 206 responses can be streamed
 %% Description: Initiates the httpc_handler process 
 %%
 %% Note: The init function may not fail, that will kill the
-%% httpc_manager process. We could make the httpc_manager more comlex
+%% httpc_manager process. We could make the httpc_manager more complex
 %% but we do not want that so errors will be handled by the process
 %% sending an init_error message to itself.
 %%--------------------------------------------------------------------
@@ -497,7 +497,7 @@ do_handle_cast({cancel, _},
 
 do_handle_cast(stream_next, #state{session = Session} = State) ->
     activate_once(Session), 
-    %% Inactivate the #state.once here because we don't want
+    %% Deactivate the #state.once here because we don't want
     %% next_body_chunk/1 to activate the socket twice.
     {noreply, State#state{once = inactive}}.
 
@@ -602,8 +602,8 @@ do_handle_info({Proto, Socket, Data},
     {noreply, State};
 
 %% The Server may close the connection to indicate that the
-%% whole body is now sent instead of sending a lengh
-%% indicator. In this case the lengh indicator will be
+%% whole body is now sent instead of sending a length
+%% indicator. In this case the length indicator will be
 %% -1.
 do_handle_info({Info, _}, State = #state{mfa = {_, whole_body, Args}})
   when Info =:= tcp_closed orelse
diff --git a/lib/inets/src/http_client/httpc_internal.hrl b/lib/inets/src/http_client/httpc_internal.hrl
index e6ffe0cc80..709683ffb0 100644
--- a/lib/inets/src/http_client/httpc_internal.hrl
+++ b/lib/inets/src/http_client/httpc_internal.hrl
@@ -107,7 +107,7 @@
 	  content,       % {ContentType, Body} - Current HTTP request
 	  settings      :: http_options(), % User defined settings
 	  abs_uri,       % string() ex: "http://www.erlang.org"
-	  userinfo,      % string() - optinal "<userinfo>@<host>:<port>"
+	  userinfo,      % string() - optional "<userinfo>@<host>:<port>"
 	  stream,	 % boolean() - stream async reply?
 	  headers_as_is, % boolean() - workaround for servers that does
 			 % not honor the http standard, can also be used 
diff --git a/lib/inets/src/http_client/httpc_manager.erl b/lib/inets/src/http_client/httpc_manager.erl
index d4777c4eb0..95d6bffbb3 100644
--- a/lib/inets/src/http_client/httpc_manager.erl
+++ b/lib/inets/src/http_client/httpc_manager.erl
@@ -151,7 +151,7 @@ cancel_request(RequestId, ProfileName) ->
 %%	RequestId - reference()
 %%      ProfileName = atom()
 %%
-%% Description: Inform tha manager that a request has been completed.
+%% Description: Inform the manager that a request has been completed.
 %%--------------------------------------------------------------------
 
 request_done(RequestId, ProfileName) ->
@@ -494,7 +494,7 @@ handle_call(info, _, State) ->
 
 handle_call(Req, From, #state{profile_name = ProfileName} = State) ->
     error_report(ProfileName, 
-		 "received unkown request"
+		 "received unknown request"
 		 "~n   Req:  ~p"
 		 "~n   From: ~p", [Req, From]),
     {reply, {error, 'API_violation'}, State}.
@@ -524,7 +524,7 @@ handle_cast({cancel_request, RequestId},
 	    #state{handler_db = HandlerDb} = State) ->
     case ets:lookup(HandlerDb, RequestId) of
 	[] ->
-	    %% Request already compleated nothing to 
+	    %% Request already completed nothing to 
 	    %% cancel
 	    {noreply, State};
 	[{_, Pid, _}] ->
@@ -581,7 +581,7 @@ handle_cast({store_cookies, {Cookies, _}}, State) ->
 
 handle_cast(Msg, #state{profile_name = ProfileName} = State) ->
     error_report(ProfileName, 
-		 "recived unknown message"
+		 "received unknown message"
 		 "~n   Msg: ~p", [Msg]),
     {noreply, State}.
 	    
diff --git a/lib/inets/src/http_client/httpc_response.erl b/lib/inets/src/http_client/httpc_response.erl
index eaf49f82f1..79895e447e 100644
--- a/lib/inets/src/http_client/httpc_response.erl
+++ b/lib/inets/src/http_client/httpc_response.erl
@@ -45,7 +45,7 @@ whole_body([Bin, Body, Length])  ->
     whole_body(<<Body/binary, Bin/binary>>, Length).
 
 %% Functions that may be returned during the decoding process
-%% if the input data is incompleate. 
+%% if the input data is incomplete. 
 parse_version([Bin, Version, MaxHeaderSize, Result, Relaxed]) ->
     parse_version(Bin, Version, MaxHeaderSize, Result, Relaxed).
 
@@ -65,8 +65,8 @@ whole_body(Body, Length) ->
 	N when (N < Length) andalso (N > 0)  ->
 	    {?MODULE, whole_body, [Body, Length]};
 	%% OBS!  The Server may close the connection to indicate that the
-	%% whole body is now sent instead of sending a lengh
-	%% indicator.In this case the lengh indicator will be
+	%% whole body is now sent instead of sending a length
+	%% indicator.In this case the length indicator will be
 	%% -1.
 	N when (N >= Length) andalso (Length >= 0) -> 
 	    %% Potential trailing garbage will be thrown away in
diff --git a/lib/inets/src/http_lib/http_chunk.erl b/lib/inets/src/http_lib/http_chunk.erl
index 742d634577..2634b82f33 100644
--- a/lib/inets/src/http_lib/http_chunk.erl
+++ b/lib/inets/src/http_lib/http_chunk.erl
@@ -44,7 +44,7 @@
 %%      MaxHeaderSize = integer()
 %%
 %% Description: Decodes a body encoded by the chunked transfer
-%% encoding. If the ChunkedBody is not compleate it returns {Module,
+%% encoding. If the ChunkedBody is not complete it returns {Module,
 %% Function, Args} so that decoding can be continued when more of the
 %% data has been received by calling Module:Function([NewData | Args]).
 %%
@@ -124,7 +124,7 @@ handle_headers(ResponseHeaderRecord = #http_response_h{},  ChunkedHeaders) ->
     NewHeaders#http_response_h{'transfer-encoding' = TransferEncoding}.
 
 %% Functions that may be returned during the decoding process
-%% if the input data is incompleate. 
+%% if the input data is incomplete. 
 decode_size([Bin, Rest, HexList, AccSize, Info]) ->
     decode_size(<<Rest/binary, Bin/binary>>, HexList, AccSize, Info).
 
diff --git a/lib/inets/src/http_lib/http_transport.erl b/lib/inets/src/http_lib/http_transport.erl
index 0b50b48ecc..c18c08c77c 100644
--- a/lib/inets/src/http_lib/http_transport.erl
+++ b/lib/inets/src/http_lib/http_transport.erl
@@ -126,7 +126,7 @@ connect({essl, SslConfig}, {Host, Port}, Opts0, Timeout) ->
 %%
 %% Description: Sets up socket to listen on the port Port on the local
 %% host using either gen_tcp or ssl. In the gen_tcp case the port
-%% might allready have been initiated by a wrapper-program and is
+%% might already have been initiated by a wrapper-program and is
 %% given as an Fd that can be retrieved by init:get_argument. The
 %% reason for this to enable a HTTP-server not running as root to use
 %% port 80.
@@ -361,7 +361,7 @@ close({essl, _}, Socket) ->
 %% peername(SocketType, Socket) -> {Port, SockName}
 %%     SocketType = ip_comm | {ssl, _}
 %%     Socket = socket() 
-%%     Port = integer()  (-1 if error occured)
+%%     Port = integer()  (-1 if error occurred)
 %%     PeerName = string()
 %%                          
 %% Description: Returns the address and port for the other end of a
@@ -395,7 +395,7 @@ do_peername({error, _}) ->
 %% sockname(SocketType, Socket) -> {Port, SockName}
 %%     SocketType = ip_comm | {ssl, _}
 %%     Socket = socket() 
-%%     Port = integer()  (-1 if error occured)
+%%     Port = integer()  (-1 if error occurred)
 %%     SockName = string()
 %%                          
 %% Description: Returns the address and port for the local (our) end 
diff --git a/lib/inets/src/http_server/httpd.erl b/lib/inets/src/http_server/httpd.erl
index 333adf68cc..21eb163278 100644
--- a/lib/inets/src/http_server/httpd.erl
+++ b/lib/inets/src/http_server/httpd.erl
@@ -207,7 +207,7 @@ reload(Config, Address, Port, Profile) ->
 %%%              connections is accepted.
 %%% 
 %%%              non-disturbing:
-%%%              A non-disturbing block is more gracefull. No
+%%%              A non-disturbing block is more graceful. No
 %%%              new connections are accepted, but the ongoing 
 %%%              requests are allowed to complete.
 %%%              If a timeout time is given, it waits this long before
diff --git a/lib/inets/src/http_server/httpd_acceptor.erl b/lib/inets/src/http_server/httpd_acceptor.erl
index c59a48eee0..d334b4d233 100644
--- a/lib/inets/src/http_server/httpd_acceptor.erl
+++ b/lib/inets/src/http_server/httpd_acceptor.erl
@@ -152,7 +152,7 @@ handle_error(closed, _, _) ->
 			     "badly."),
     exit(normal);
 
-%% This will only happen when the client is terminated abnormaly
+%% This will only happen when the client is terminated abnormally
 %% and is not a problem for the server, so we want
 %% to terminate normal so that we can restart without any 
 %% error messages.
diff --git a/lib/inets/src/http_server/httpd_conf.erl b/lib/inets/src/http_server/httpd_conf.erl
index 71ce852974..a91af84629 100644
--- a/lib/inets/src/http_server/httpd_conf.erl
+++ b/lib/inets/src/http_server/httpd_conf.erl
@@ -56,9 +56,9 @@ validate_ipfamily(inet6) ->
     inet6;
 %% Backwards compatibility wrapper, 
 %% fallback to the default, IPV4,
-%% as it will most proably work.
+%% as it will most probably work.
 %% IPv6 standard moved away from 
-%% beeing able to fallback to ipv4
+%% being able to fallback to ipv4
 validate_ipfamily(inet6fb4) ->
     inet;
 validate_ipfamily(IpFamilyStr) ->
@@ -208,7 +208,7 @@ validate_config_params([{socket_type, ip_comm} | Rest]) ->
 validate_config_params([{socket_type, {Value, Opts}} | Rest]) when Value == ip_comm; 
 								   Value == ssl; 
 								   Value == essl ->
-    %% Make sure not to set socket values used internaly
+    %% Make sure not to set socket values used internally
     validate_config_params(Opts), 
     validate_config_params(Rest);
 
@@ -449,7 +449,7 @@ store(ConfigListEntry, _ConfigList) ->
 %%   os:      "inets/1.2.3 (unix)
 %%   full:    "inets/1.2.3 (unix/linux) OTP/R15B"
 %% Note that the format of SERVER_SOFTWARE is that of 'minimal'.
-%% Also, there will always be atleast two digits in a version: 
+%% Also, there will always be at least two digits in a version: 
 %% Not just 1 but 1.0
 %% 
 %% We have already checked that the value is valid, 
diff --git a/lib/inets/src/http_server/httpd_request.erl b/lib/inets/src/http_server/httpd_request.erl
index 6643664a2a..a16df6914a 100644
--- a/lib/inets/src/http_server/httpd_request.erl
+++ b/lib/inets/src/http_server/httpd_request.erl
@@ -50,7 +50,7 @@ parse(Unknown) ->
     exit({bad_args, Unknown}).
 
 %% Functions that may be returned during the decoding process
-%% if the input data is incompleate. 
+%% if the input data is incomplete. 
 parse_method([Bin, Method, Current, Max, Options, Result]) ->
     parse_method(Bin, Method, Current, Max, Options, Result).
 
@@ -351,7 +351,7 @@ validate_version(_) ->
 validate_version(_) ->
     false.
 %%----------------------------------------------------------------------
-%% There are 3 possible forms of the reuqest URI 
+%% There are 3 possible forms of the request URI 
 %%
 %%  1. * When the request is not for a special assset. is is instead
 %%     to the server itself
@@ -402,7 +402,7 @@ get_persistens(HTTPVersion,ParsedHeader,ConfigDB)->
     case httpd_util:lookup(ConfigDB, keep_alive, true) of
 	true->
 	    case HTTPVersion of
-		%%If it is version prio to 1.1 kill the conneciton
+		%%If it is version prio to 1.1 kill the connection
 		"HTTP/1." ++ NList ->
 		    case proplists:get_value("connection", ParsedHeader,
 					     "keep-alive") of  
diff --git a/lib/inets/src/http_server/httpd_request_handler.erl b/lib/inets/src/http_server/httpd_request_handler.erl
index 298919d91a..e38bc39630 100644
--- a/lib/inets/src/http_server/httpd_request_handler.erl
+++ b/lib/inets/src/http_server/httpd_request_handler.erl
@@ -76,7 +76,7 @@ start_link(Manager, ConfigDB, AcceptTimeout) ->
 %%
 %% Description: Send a message to the request handler process
 %% confirming that the socket ownership has now sucssesfully been
-%% transfered to it. Intended to be called by the httpd acceptor
+%% transferred to it. Intended to be called by the httpd acceptor
 %% process.
 %%--------------------------------------------------------------------
 socket_ownership_transfered(Pid, SocketType, Socket) ->
diff --git a/lib/inets/src/http_server/httpd_util.erl b/lib/inets/src/http_server/httpd_util.erl
index 7bc97bc230..b4e49dc7f0 100644
--- a/lib/inets/src/http_server/httpd_util.erl
+++ b/lib/inets/src/http_server/httpd_util.erl
@@ -548,7 +548,7 @@ search_and_replace(S,A,B) ->
 
 
 %%----------------------------------------------------------------------
-%% Converts  a string that constists of 0-9,A-F,a-f to a 
+%% Converts  a string that consists of 0-9,A-F,a-f to a 
 %% integer
 %%----------------------------------------------------------------------
 
diff --git a/lib/inets/src/http_server/mod_auth.erl b/lib/inets/src/http_server/mod_auth.erl
index a7c4b39c5c..6d9d73d552 100644
--- a/lib/inets/src/http_server/mod_auth.erl
+++ b/lib/inets/src/http_server/mod_auth.erl
@@ -435,7 +435,7 @@ check_password(User, Password, _Dir, DirData) ->
     end.
 
 
-%% Middle API. Theese functions call the appropriate authentication module.
+%% Middle API. These functions call the appropriate authentication module.
 int_get_user(DirData, User) ->    
     AuthMod = auth_mod_name(DirData), 
     apply(AuthMod, get_user, [DirData, User]).
diff --git a/lib/inets/src/http_server/mod_auth_server.erl b/lib/inets/src/http_server/mod_auth_server.erl
index 90d9ee34b1..81229531ab 100644
--- a/lib/inets/src/http_server/mod_auth_server.erl
+++ b/lib/inets/src/http_server/mod_auth_server.erl
@@ -177,7 +177,7 @@ handle_call({delete_group_member, Addr, Port, Profile, Dir, Group, User, AuthPwd
 		     AuthPwd, State), 
     {reply, Reply, State};
 
-%% List all users thats standalone users
+%% List all users that's standalone users
 handle_call({list_users, Addr, Port, Profile, Dir, AuthPwd}, _From, State) ->
     Reply = api_call(Addr, Port, Profile, Dir, list_users, [], AuthPwd, State),
     {reply, Reply, State};
diff --git a/lib/inets/src/http_server/mod_disk_log.erl b/lib/inets/src/http_server/mod_disk_log.erl
index a6e45df5f3..f0bcd2dcdc 100644
--- a/lib/inets/src/http_server/mod_disk_log.erl
+++ b/lib/inets/src/http_server/mod_disk_log.erl
@@ -240,7 +240,7 @@ create_disk_log(LogFile, SizeTag, ConfigList) ->
 		undefined ->
 		    {error,
 		     ?NICE(Filename++
-			   " is an invalid ErrorLog beacuse ServerRoot "
+			   " is an invalid ErrorLog because ServerRoot "
 			   "is not defined")};
 		ServerRoot ->
 		    AbsoluteFilename = filename:join(ServerRoot,Filename),
@@ -263,7 +263,7 @@ create_disk_log(Filename, MaxBytes, MaxFiles, ConfigList) ->
 %%
 %% When the internal disk log format is used, we will do some extra 
 %% controls. If the files are valid, try to repair them and if 
-%% thats not possible, truncate.
+%% that's not possible, truncate.
 %%----------------------------------------------------------------------
 
 open(Filename, MaxBytes, MaxFiles, internal) ->
diff --git a/lib/inets/src/http_server/mod_log.erl b/lib/inets/src/http_server/mod_log.erl
index 6e050a2106..f4cb97108b 100644
--- a/lib/inets/src/http_server/mod_log.erl
+++ b/lib/inets/src/http_server/mod_log.erl
@@ -224,7 +224,7 @@ create_log(LogFile, ConfigList) ->
 		undefined ->
 		    {error,
 		     ?NICE(Filename++
-			   " is an invalid logfile name beacuse "
+			   " is an invalid logfile name because "
 			   "ServerRoot is not defined")};
 		ServerRoot ->
 		    AbsoluteFilename=filename:join(ServerRoot,Filename),
diff --git a/lib/inets/src/http_server/mod_range.erl b/lib/inets/src/http_server/mod_range.erl
index a90ef84419..4391785227 100644
--- a/lib/inets/src/http_server/mod_range.erl
+++ b/lib/inets/src/http_server/mod_range.erl
@@ -82,7 +82,7 @@ send_range_response(Path, Info, Ranges, FileInfo, LastModified)->
 				LastModified)
     end.
 %%More than one range specified
-%%Send a multipart reponse to the user
+%%Send a multipart response to the user
 %
 %%An example of an multipart range response
 
@@ -342,7 +342,7 @@ get_file_chunk_size(Position, End, _DefaultChunkSize) ->
 
 %Get the size of the range to send. Remember that
 %A range is from startbyte up to endbyte which means that
-%the nuber of byte in a range is (StartByte-EndByte)+1
+%the number of byte in a range is (StartByte-EndByte)+1
 
 get_range_size(from_end, Stop, _FileInfo)->
     integer_to_list(-1*Stop);
@@ -377,7 +377,7 @@ format_range({StartByte,[]})->
     {from_start,list_to_integer(StartByte)};
 format_range({StartByte,EndByte})->        
     {list_to_integer(StartByte),list_to_integer(EndByte)}.
-%Last case return the splitted range
+%Last case return the split range
 split_range([],Current,Other)->
     {lists:reverse(Other),lists:reverse(Current)};
 
diff --git a/lib/inets/src/http_server/mod_responsecontrol.erl b/lib/inets/src/http_server/mod_responsecontrol.erl
index 3bd6340894..42033024c4 100644
--- a/lib/inets/src/http_server/mod_responsecontrol.erl
+++ b/lib/inets/src/http_server/mod_responsecontrol.erl
@@ -48,8 +48,8 @@ do(Info) ->
     end.
 
 %%----------------------------------------------------------------------
-%%Control that the request header did not contians any limitations 
-%%wheather a response shall be createed or not
+%%Control that the request header did not contains any limitations 
+%%whether a response shall be createed or not
 %%----------------------------------------------------------------------
 do_responsecontrol(Info) ->
     ?DEBUG("do_response_control -> Request URI: ~p",[Info#mod.request_uri]),
@@ -59,7 +59,7 @@ do_responsecontrol(Info) ->
 	    control(Path, Info, FileInfo);
 	_ ->
 	    %% The requested asset is not a plain file and then it must 
-	    %% be generated everytime its requested
+	    %% be generated every time its requested
 	    continue
     end.
 
@@ -180,7 +180,7 @@ control_match(Info, _FileInfo, HeaderField, FileEtag)->
  	undefined->
 	    undefined;
         Etags->
-	    %%Control that the match any star not is availible 
+	    %%Control that the match any star not is available 
 	    case lists:member("*",Etags) of
 		true-> 
 		    match;
diff --git a/lib/inets/src/http_server/mod_security.erl b/lib/inets/src/http_server/mod_security.erl
index 7d9fd5fa2d..15451a5dd5 100644
--- a/lib/inets/src/http_server/mod_security.erl
+++ b/lib/inets/src/http_server/mod_security.erl
@@ -93,7 +93,7 @@ do(Info) ->
 		    {proceed, [{status, {403, Info#mod.request_uri, ""}} |
 			       Info#mod.data]};
 		false ->
-		    report_failed(Info, User,"Authentication Succedded"),
+		    report_failed(Info, User,"Authentication Succeeded"),
 		    mod_security_server:store_successful_auth(Addr, Port, Profile, 
 							      User, 
 							      SDirData),
diff --git a/lib/inets/src/http_server/mod_security_server.erl b/lib/inets/src/http_server/mod_security_server.erl
index 4f52357af3..177b36a2a9 100644
--- a/lib/inets/src/http_server/mod_security_server.erl
+++ b/lib/inets/src/http_server/mod_security_server.erl
@@ -24,7 +24,7 @@
 %% The gen_server code.
 %%
 %% A gen_server is needed in this module to take care of shared access to the
-%% data file used to store failed and successful authentications aswell as 
+%% data file used to store failed and successful authentications as well as 
 %% user blocks.
 %%
 %% The storage model is a write-through model with both an ets and a dets 
@@ -464,7 +464,7 @@ list_blocked([{_Name, {ETS, _DETS}}|Tables], Addr, Port, Profile, Dir, Acc) ->
     list_blocked(Tables, Addr, Port, Profile, Dir, NewBlocked).
 
 
-%% Reads dets-table DETS and syncronizes it with the ets-table ETS.
+%% Reads dets-table DETS and synchronizes it with the ets-table ETS.
 %%
 sync_dets_to_ets(DETS, ETS) ->
     dets:traverse(DETS, fun(X) ->
@@ -475,7 +475,7 @@ sync_dets_to_ets(DETS, ETS) ->
 %% Check if a specific user is blocked from access.
 %%
 %% The sideeffect of this routine is that it unblocks also other users
-%% whos blocking time has expired. This to keep the tables as small
+%% whose blocking time has expired. This to keep the tables as small
 %% as possible.
 %%
 check_blocked_user(Info, User, Dir, Addr, Port, Profile, ETS, DETS, CBModule) ->
diff --git a/lib/inets/src/inets_app/inets.erl b/lib/inets/src/inets_app/inets.erl
index 64963957ca..b79accdaf2 100644
--- a/lib/inets/src/inets_app/inets.erl
+++ b/lib/inets/src/inets_app/inets.erl
@@ -69,14 +69,14 @@ start(Type) ->
 %%
 %% Note: Dynamically started services will not be handled by
 %% application takeover and failover behavior when inets is run as a
-%% distributed application. Nor will they be automaticly restarted
+%% distributed application. Nor will they be automatically restarted
 %% when the inets application is restarted, but as long as the inets
 %% application is up and running they will be supervised and may be
 %% soft code upgraded. Services started with the option stand alone,
 %% e.i. the service is not started as part of the inets application,
 %% will lose all OTP application benefits such as soft upgrade. The
 %% stand alone service will be linked to the process that started it.
-%% In most cases some of the supervison functionallity will still be
+%% In most cases some of the supervison functionality will still be
 %% in place and in some sense the calling process has now become the
 %% top supervisor.
 %% --------------------------------------------------------------------
@@ -396,7 +396,7 @@ service_names() ->
 %% Note that it starts a tracer server.
 %% When Destination is the atom io (or the tuple {io, Verbosity}),
 %% all (printable) inets trace events (trace_ts events which has
-%% Severity withing Limit) will be written to stdout using io:format.
+%% Severity within Limit) will be written to stdout using io:format.
 %%
 %%-----------------------------------------------------------------
 enable_trace(Level, Dest)          -> inets_trace:enable(Level, Dest).
diff --git a/lib/inets/src/inets_app/inets_lib.erl b/lib/inets/src/inets_app/inets_lib.erl
index 3fae376a9f..142a03575c 100644
--- a/lib/inets/src/inets_app/inets_lib.erl
+++ b/lib/inets/src/inets_app/inets_lib.erl
@@ -35,11 +35,11 @@ millisec_passed(T0) ->
 			     native,
 			     micro_seconds) div 1000.
 
-%% Return formated time stamp (e.g. 2015:03:16 10:05:23 1234)
+%% Return formatted time stamp (e.g. 2015:03:16 10:05:23 1234)
 formated_timestamp() ->
     format_timestamp( os:timestamp() ).
 
-%% Return formated time stamp (e.g. 2015:03:16 10:05:23 1234)
+%% Return formatted time stamp (e.g. 2015:03:16 10:05:23 1234)
 format_timestamp({_N1, _N2, N3} = Tme) ->
     {Date, Time}   = calendar:now_to_datetime(Tme),
     {YYYY,MM,DD}   = Date,
diff --git a/lib/inets/src/inets_app/inets_service.erl b/lib/inets/src/inets_app/inets_service.erl
index 3441d2a2e4..c2eaf2aefb 100644
--- a/lib/inets/src/inets_app/inets_service.erl
+++ b/lib/inets/src/inets_app/inets_service.erl
@@ -55,7 +55,7 @@
 %% Returns list of running services. Services started as stand alone
 %% are not listed 
 %% services() -> % [{Service, Pid}] 
-%% Exampel:
+%% Example:
 %% services() ->
 %%   [{httpc, Pid} || {_, Pid, _, _} <- 
 %%			supervisor:which_children(httpc_profile_sup)].
diff --git a/lib/inets/src/inets_app/inets_trace.erl b/lib/inets/src/inets_app/inets_trace.erl
index 8615540172..5ed71c9088 100644
--- a/lib/inets/src/inets_app/inets_trace.erl
+++ b/lib/inets/src/inets_app/inets_trace.erl
@@ -56,7 +56,7 @@
 %% Note that it starts a tracer server.
 %% When Destination is the atom io (or the tuple {io, Verbosity}),
 %% all (printable) inets trace events (trace_ts events which has
-%% Severity withing Limit) will be written to stdout using io:format.
+%% Severity within Limit) will be written to stdout using io:format.
 %%
 %%-----------------------------------------------------------------
 enable(Level, Dest) ->
diff --git a/lib/inets/test/erl_make_certs.erl b/lib/inets/test/erl_make_certs.erl
index 2db95825bc..e52f40216a 100644
--- a/lib/inets/test/erl_make_certs.erl
+++ b/lib/inets/test/erl_make_certs.erl
@@ -45,7 +45,7 @@
 %%      {title, Title}
 %%      {dnQualifer, DnQ}
 %%   issuer = {Issuer, IssuerKey}                   true (i.e. a ca cert is created) 
-%%                                                  (obs IssuerKey migth be {Key, Password}
+%%                                                  (obs IssuerKey might be {Key, Password}
 %%   key = KeyFile|KeyBin|rsa|dsa|ec                Subject PublicKey rsa, dsa or ec generates key
 %%   
 %%
diff --git a/lib/inets/test/http_format_SUITE.erl b/lib/inets/test/http_format_SUITE.erl
index 639e1a4571..f8227789c5 100644
--- a/lib/inets/test/http_format_SUITE.erl
+++ b/lib/inets/test/http_format_SUITE.erl
@@ -298,7 +298,7 @@ chunk_max_bodysize(Config) when is_list(Config) ->
 %%-------------------------------------------------------------------------
 http_response() ->
     [{doc, "Test httpc_response:parse*. This test case will simulate that the "
-     "message will be recived a little at the time on a socket and the "
+     "message will be received a little at the time on a socket and the "
      "package may be broken up into smaller parts at arbitrary point."}].
 http_response(Config) when is_list(Config) ->
 
@@ -369,7 +369,7 @@ http_response(Config) when is_list(Config) ->
 %%-------------------------------------------------------------------------
 http_request() ->
     [{doc, "Test httpd_request:parse* This test case will simulate that the " 
-     "message will be recived a little at the time on a socket and the " 
+     "message will be received a little at the time on a socket and the " 
       "package may be broken up into smaller parts at arbitrary point."}].
 http_request(Config) when is_list(Config) ->
 
@@ -450,7 +450,7 @@ http_request(Config) when is_list(Config) ->
 validate_request_line() ->
     [{doc, "Test httpd_request:validate/3. Makes sure you can not get past"
      " the server_root and that the request is recognized by the server"
-     " and protcol version."}].
+     " and protocol version."}].
 validate_request_line(Config) when is_list(Config) ->
 
     %% HTTP/0.9 only has GET requests
@@ -548,7 +548,7 @@ esi_parse_headers(Config) when is_list(Config) ->
 %%--------------------------------------------------------------------
 cgi_parse_headers() ->
     [{doc, "Test httpd_cgi:*. This test case will simulate that the "
-     "message will be recived a little at the time on a socket and the "
+     "message will be received a little at the time on a socket and the "
      "package may be broken up into smaller parts at arbitrary point."}].
 
 cgi_parse_headers(Config) when is_list(Config) ->
diff --git a/lib/inets/test/httpc_SUITE.erl b/lib/inets/test/httpc_SUITE.erl
index f7eff5822d..77a56cf1b8 100644
--- a/lib/inets/test/httpc_SUITE.erl
+++ b/lib/inets/test/httpc_SUITE.erl
@@ -537,7 +537,7 @@ pipeline(Config) when is_list(Config) ->
     Request  = {url(group_name(Config), "/dummy.html", Config), []},
     {ok, _} = httpc:request(get, Request, [], [], pipeline),
 
-    %% Make sure pipeline session is registerd
+    %% Make sure pipeline session is registered
     ct:sleep(4000),
     keep_alive_requests(Request, pipeline).
 
@@ -547,7 +547,7 @@ persistent_connection(Config) when is_list(Config) ->
     Request  = {url(group_name(Config), "/dummy.html", Config), []},
     {ok, _} = httpc:request(get, Request, [], [], persistent),
 
-    %% Make sure pipeline session is registerd
+    %% Make sure pipeline session is registered
     ct:sleep(4000),
     keep_alive_requests(Request, persistent).
 
@@ -966,7 +966,7 @@ no_content_204(Config) when is_list(Config) ->
 
 tolerate_missing_CR() ->
     [{doc, "Test the case that the HTTP server uses only LF instead of CRLF"
-     "as delimitor. Solves OTP-7304"}].
+     "as delimiter. Solves OTP-7304"}].
 tolerate_missing_CR(Config) when is_list(Config) ->
     URL = url(group_name(Config), "/missing_CR.html", Config),
     {ok, {{_,200,_}, _, [_ | _]}} = httpc:request(URL).
@@ -1182,7 +1182,7 @@ headers_dummy(Config) when is_list(Config) ->
 
     %% The dummy server will ignore the headers, we only want to test
     %% that the client header-handling code. This would not
-    %% be a vaild http-request!
+    %% be a valid http-request!
     {ok, {{_,200,_}, [_ | _], [_|_]}} =
 	httpc:request(post,
 		     {URL,
@@ -1562,7 +1562,7 @@ custom_receive() ->
             ct:log("Message received: ~p", [Msg])
     after
         1000 ->
-            ct:fail("Timeout: did not recive packet")
+            ct:fail("Timeout: did not receive packet")
     end.
 
 %% Custom server is used to test special cases when using chunked encoding
@@ -1681,7 +1681,7 @@ chunkify_receive() ->
             end
     after
         1000 ->
-            ct:fail("Timeout: did not recive packet")
+            ct:fail("Timeout: did not receive packet")
     end.
 
 %%--------------------------------------------------------------------
@@ -2356,14 +2356,14 @@ content_type_header([{"content-type", Value}|_]) ->
 auth_header([_ | Tail]) ->
     auth_header(Tail).
 
-handle_auth("Basic " ++ UserInfo, Challange, DefaultResponse) ->
+handle_auth("Basic " ++ UserInfo, Challenge, DefaultResponse) ->
     case string:tokens(base64:decode_to_string(UserInfo), ":") of
 	["alladin", "sesame"] = Auth ->
 	    ct:print("Auth: ~p~n", [Auth]),
 	    DefaultResponse;
 	Other ->
 	    ct:print("UnAuth: ~p~n", [Other]),
-	    Challange
+	    Challenge
     end.
 
 check_cookie([]) ->
@@ -2572,14 +2572,14 @@ handle_uri(_,"/redirectloop.html",Port,_,Socket,_) ->
 	++ "\r\n\r\n" ++ Body;
 
 handle_uri(_,"/userinfo.html", _,Headers,_, DefaultResponse) ->
-    Challange = "HTTP/1.1 401 Unauthorized \r\n" ++
+    Challenge = "HTTP/1.1 401 Unauthorized \r\n" ++
 	"WWW-Authenticate:Basic" ++"\r\n" ++
 	"Content-Length:0\r\n\r\n",
     case auth_header(Headers) of
 	{ok, Value} ->
-	    handle_auth(Value, Challange, DefaultResponse);
+	    handle_auth(Value, Challenge, DefaultResponse);
 	_ ->
-	    Challange
+	    Challenge
     end;
 
 handle_uri(_,"/dummy_headers.html",_,_,Socket,_) ->
diff --git a/lib/inets/test/httpc_cookie_SUITE.erl b/lib/inets/test/httpc_cookie_SUITE.erl
index 8140967bca..609c910144 100644
--- a/lib/inets/test/httpc_cookie_SUITE.erl
+++ b/lib/inets/test/httpc_cookie_SUITE.erl
@@ -136,7 +136,7 @@ netscape_cookies(Config) when is_list(Config) ->
 
 cookie_cancel() -> 
     [{doc, "A cookie can be canceld by sending the same cookie with max-age=0 "
-     "this test cheks that cookie is canceled."}].
+     "this test checks that cookie is canceled."}].
 cookie_cancel(Config) when is_list(Config) -> 
     SetCookieHeaders = [{"set-cookie", "test_cookie=true; path=/;" 
 			 "max-age=60000"}],
@@ -160,7 +160,7 @@ cookie_expires(Config) when is_list(Config) ->
     {"cookie", ""} = httpc:cookie_header(?URL).
 
 persistent_cookie() ->
-    [{doc, "Test domian cookie attribute"}].
+    [{doc, "Test domain cookie attribute"}].
 persistent_cookie(Config) when is_list(Config)->
     SetCookieHeaders = [{"set-cookie", "test_cookie=true; path=/;" 
 			 "max-age=60000"}],
@@ -176,7 +176,7 @@ persistent_cookie(Config) when is_list(Config)->
     {"cookie","$Version=0; test_cookie=true; $Path=/"} = httpc:cookie_header(?URL).
 
 domain_cookie() ->
-    [{doc, "Test the domian cookie attribute"}].
+    [{doc, "Test the domain cookie attribute"}].
 domain_cookie(Config) when is_list(Config) ->
     SetCookieHeaders = [{"set-cookie", "test_cookie=true; path=/;" 
 			 "domain=.cookie.test.org"}],
diff --git a/lib/inets/test/httpc_proxy_SUITE.erl b/lib/inets/test/httpc_proxy_SUITE.erl
index a6de776721..6abc136e66 100644
--- a/lib/inets/test/httpc_proxy_SUITE.erl
+++ b/lib/inets/test/httpc_proxy_SUITE.erl
@@ -314,7 +314,7 @@ http_proxy_auth(doc) ->
 http_proxy_auth(Config) when is_list(Config) ->
     %% Our proxy seems to ignore the header, however our proxy
     %% does not requirer an auth header, but we want to know
-    %% atleast the code for sending the header does not crash!
+    %% at least the code for sending the header does not crash!
     Method = get,
     URL = url("/index.html", Config),
     Request = {URL,[]},
diff --git a/lib/inets/test/httpd_1_1.erl b/lib/inets/test/httpd_1_1.erl
index ce9f7acc4d..298c7150fd 100644
--- a/lib/inets/test/httpd_1_1.erl
+++ b/lib/inets/test/httpd_1_1.erl
@@ -178,7 +178,7 @@ if_test(Type, Port, Host, Node, DocRoot)->
     
     Mod2 =  httpd_util:rfc1123_date(calendar:gregorian_seconds_to_datetime(
     				      CreatedSec+1)),
-    %% Control that the If-Unmodified-Header lmits the response
+    %% Control that the If-Unmodified-Header limits the response
     ok = httpd_test_lib:verify_request(Type,Host,Port,Node, 
 				       "GET / HTTP/1.1\r\nHost:"
 				       ++ Host ++ 
@@ -365,7 +365,7 @@ validateMultiPartRangeRequest(Body, ValidBody, Boundary)->
     case re:split(Body,"--"++Boundary++"--", [{return, list}]) of
 	%%Last is the epilogue and must be ignored 
 	[First | _Last]->
-	    %%First is now the actuall http request body.
+	    %%First is now the actual http request body.
 	    case re:split(First, "--" ++ Boundary, [{return, list}]) of
 		%%Parts is now a list of ranges and the heads for each range
 		%%Gues we try to split out the body
diff --git a/lib/inets/test/httpd_SUITE.erl b/lib/inets/test/httpd_SUITE.erl
index b3eae4740c..b39ae6425a 100644
--- a/lib/inets/test/httpd_SUITE.erl
+++ b/lib/inets/test/httpd_SUITE.erl
@@ -882,7 +882,7 @@ chunked(Config) when is_list(Config) ->
 %%-------------------------------------------------------------------------
 expect() ->   
     ["Check that the server handles request with the expect header "
-     "field appropiate"].
+     "field appropriate"].
 expect(Config) when is_list(Config) ->
     httpd_1_1:expect(proplists:get_value(type, Config), proplists:get_value(port, Config), 
 		     proplists:get_value(host, Config), proplists:get_value(node, Config)).
diff --git a/lib/inets/test/httpd_basic_SUITE.erl b/lib/inets/test/httpd_basic_SUITE.erl
index cb2646c02b..c6b35eb756 100644
--- a/lib/inets/test/httpd_basic_SUITE.erl
+++ b/lib/inets/test/httpd_basic_SUITE.erl
@@ -397,7 +397,7 @@ slowdose(Config) when is_list(Config) ->
 %%-------------------------------------------------------------------------
 
 invalid_rfc1123_date() ->
-    [{doc, "Test that a non-DST date is handled correcly"}].
+    [{doc, "Test that a non-DST date is handled correctly"}].
 invalid_rfc1123_date(Config) when is_list(Config) ->
     Rfc1123FormattedDate = "Sun, 26 Mar 2017 01:00:00 GMT",
     NonDSTDateTime = {{2017, 03, 26},{1, 0, 0}},
diff --git a/lib/inets/test/httpd_mod.erl b/lib/inets/test/httpd_mod.erl
index 6e3635001a..3daeb4f889 100644
--- a/lib/inets/test/httpd_mod.erl
+++ b/lib/inets/test/httpd_mod.erl
@@ -550,7 +550,7 @@ htaccess(Type, Port, Host, Node) ->
     auth_request(Type, Host, Port, Node, "/ht/open/","Aladdin", 
 		 "AladdinPassword", [{statuscode, 200}]),
     
-    %% Contro that bad passwords and userids get a good denial
+    %% Control that bad passwords and userids get a good denial
     %% User correct but wrong password! ["one:one" user first in user list]
     auth_request(Type, Host, Port, Node, "/ht/open/", "one", "one", 
 		 [{statuscode, 401}]),
@@ -558,7 +558,7 @@ htaccess(Type, Port, Host, Node) ->
     auth_request(Type, Host, Port, Node, "/ht/open/", "dummy", "dummy", 
 		 [{statuscode, 401}]),
     
-    %% Control that authetication still works, even if its a member in a group
+    %% Control that authentication still works, even if its a member in a group
     %% Authentication OK! ["two:TwoPassword" user in first group]
     auth_request(Type, Host, Port, Node, "/ht/secret/dummy.html", "two", 
 		 "TwoPassword", [{statuscode, 200}]),
diff --git a/lib/inets/test/httpd_test_data/server_root/conf/httpd.conf b/lib/inets/test/httpd_test_data/server_root/conf/httpd.conf
index 3add93cd73..9377082b9d 100644
--- a/lib/inets/test/httpd_test_data/server_root/conf/httpd.conf
+++ b/lib/inets/test/httpd_test_data/server_root/conf/httpd.conf
@@ -30,9 +30,9 @@ Port 8888
 # 
 # It is also possible to specify the ip-family with the directive.
 # There ar three possible value: inet, inet6 and inet6fb4
-# inet:     Use IpFamily inet when retreiving the address and
+# inet:     Use IpFamily inet when retrieving the address and
 #           fail if that does not work.
-# inet6:    Use IpFamily inet6 when retreiving the address and
+# inet6:    Use IpFamily inet6 when retrieving the address and
 #           fail if that does not work.
 # inet6fb4: First IpFamily inet6 is tried and if that does not work, 
 #           inet is used as fallback. 
@@ -206,7 +206,7 @@ SSLCertificateFile /var/tmp/server_root/ssl/ssl_server.pem
 SSLCertificateKeyFile /var/tmp/server_root/ssl/ssl_server.pem
 
 # Set SSLVerifyClient to:
-# 0 if no certicate is required
+# 0 if no certificate is required
 # 1 if the client may present a valid certificate
 # 2 if the client must present a valid certificate
 # 3 if the client may present a valid certificate but it is not required to
diff --git a/lib/inets/test/httpd_test_data/server_root/icons/README b/lib/inets/test/httpd_test_data/server_root/icons/README
index a1fc5a5a9c..c53bba67c4 100644
--- a/lib/inets/test/httpd_test_data/server_root/icons/README
+++ b/lib/inets/test/httpd_test_data/server_root/icons/README
@@ -46,7 +46,7 @@ Please feel free to tweak and rename the icons as you like.
           This can be used as a placeholder or a spacing element.
 
      bomb.gif
-          This can be used to repreesnt core files.
+          This can be used to represent core files.
 
      box1.gif, box2.gif
           These icons can be used to represent generic 3D applications and
diff --git a/lib/inets/test/httpd_time_test.erl b/lib/inets/test/httpd_time_test.erl
index e858ddf4f6..81a76c097e 100644
--- a/lib/inets/test/httpd_time_test.erl
+++ b/lib/inets/test/httpd_time_test.erl
@@ -134,13 +134,13 @@ loop(Pollers, Timeout) ->
 		    exit({fail, {poller_exit, Pid, Time, Reason}});
 		false ->
 		    error_msg("received unexpected ~p from ~p"
-			      "befor completion of test", [Reason, Pid]),
+			      "before completion of test", [Reason, Pid]),
 		    loop(Pollers, Timeout - inets_lib:millisec_passed(Start))
 	    end;
 
 	{poller_stat_failure, Pid, {SocketType, Host, Port, Time, Reason}} ->
 	    error_msg("received stat failure ~p from poller ~p after ~p "
-		      "befor completion of test" 
+		      "before completion of test" 
 		      "~n   SocketType: ~p"
 		      "~n   Host:       ~p"
 		      "~n   Port:       ~p", 
@@ -149,7 +149,7 @@ loop(Pollers, Timeout) ->
 
 	{poller_stat_failure, Pid, SocketType, Host, Port, Reason} ->
 	    error_msg("received stat failure ~p from poller ~p "
-		      "befor completion of test" 
+		      "before completion of test" 
 		      "~n   SocketType: ~p"
 		      "~n   Host:       ~p"
 		      "~n   Port:       ~p", 
@@ -157,7 +157,7 @@ loop(Pollers, Timeout) ->
 	    exit({fail, {poller_failure, Pid, Reason}});
 
 	Any ->
-	    error_msg("received unexpected message befor completion of test: "
+	    error_msg("received unexpected message before completion of test: "
 		      "~n   ~p", [Any]),
 	    exit({fail, Any})
 
diff --git a/lib/inets/src/http_server/httpd_response.erl b/lib/inets/src/http_server/httpd_response.erl
index 062bf34d8e..36388891c1 100644
--- a/lib/inets/src/http_server/httpd_response.erl
+++ b/lib/inets/src/http_server/httpd_response.erl
@@ -154,8 +154,8 @@ send_response(ModData, Header, Body) ->
 	undefined ->
 	    %% No status code 
 	    %% Ooops this must be very bad:
-	    %% generate a 404 content not availible
-	    send_status(ModData, 404, "The file is not availible");
+	    %% generate a 404 content not available
+	    send_status(ModData, 404, "The file is not available");
 	StatusCode ->
 	    case send_header(ModData, StatusCode, lists:keydelete(code, 1,
 								  Header)) of
@@ -176,7 +176,7 @@ send_header(#mod{socket_type  = Type,
 		     %% May be implicit!
 		     "HTTP/0.9";
 		 {unknown, 408} ->
-		     %% This will proably never happen! It means the
+		     %% This will probably never happen! It means the
 		     %% server has timed out the request without
 		     %% receiving a version for the request!  Send the
 		     %% lowest version so to ensure that the client
-- 
2.31.1

openSUSE Build Service is sponsored by